@@ -28,7 +28,8 @@
 #include "egg/egg-error.h"
 #include "egg/egg-secure-memory.h"
 
-#include "gcr/gcr-parser.h"
+#include "gcr/gcr.h"
+#include "gcr/gcr-internal.h"
 
 #include "gck/gck.h"
 
@@ -91,20 +92,20 @@ authenticate (GcrParser *par, gint state, gpointer user_data)
 	};
 } 
 
-DEFINE_SETUP(parser)
+TESTING_SETUP(parser)
 {
 	parser = gcr_parser_new ();
 	g_signal_connect (parser, "parsed", G_CALLBACK (parsed_item), parser);
 	g_signal_connect (parser, "authenticate", G_CALLBACK (authenticate), parser);
 }
 
-DEFINE_TEARDOWN(parser)
+TESTING_TEARDOWN(parser)
 {
 	g_object_unref (parser);
 	parser = NULL;
 }
 
-DEFINE_TEST(parse_all)
+TESTING_TEST(parse_all)
 {
 	guchar *contents;
 	GError *err = NULL;
@@ -127,6 +128,8 @@ DEFINE_TEST(parse_all)
 		contents = testing_data_read (filename, &len);
 		
 		result = gcr_parser_parse_data (parser, contents, len, &err);
+		g_free (contents);
+
 		if (!result) { 
 			g_warning ("couldn't parse file data: %s: %s", 
 			           filename, egg_error_message (err));
